ntpd: abs(tmx.offset) was truncating a "long" typed value

Signed-off-by: Denys Vlasenko <vda.linux@googlemail.com>
diff --git a/networking/ntpd.c b/networking/ntpd.c
index 47410c2..e11160a 100644
--- a/networking/ntpd.c
+++ b/networking/ntpd.c
@@ -1876,9 +1876,11 @@
 //15:31:53.473 update from:<IP> offset:+0.000007 delay:0.158142 jitter:0.010922 clock drift:+9.343ppm tc:6
 //15:32:58.902 update from:<IP> offset:-0.000728 delay:0.158222 jitter:0.009454 clock drift:+9.298ppm tc:6
 			/*
 			 * This expression would choose MIN_FREQHOLD + 8 in the above example.
 			 */
-			G.FREQHOLD_cnt = 1 + MIN_FREQHOLD + ((unsigned)(abs(tmx.offset)) >> 16);
+			unsigned off_065 = abs((int)(tmx.offset >> 16));
+			G.FREQHOLD_cnt = 1 + MIN_FREQHOLD + off_065;
 		}
 		G.FREQHOLD_cnt--;
 		tmx.status |= STA_FREQHOLD;
@@ -1876,9 +1876,11 @@
 //15:32:58.902 update from:<IP> offset:-0.000728 delay:0.158222 jitter:0.009454 clock drift:+9.298ppm tc:6
 			/*
-			 * This expression would choose MIN_FREQHOLD + 8 in the above example.
+			 * This expression would choose MIN_FREQHOLD + 8 in the above example
+			 * (off_065 is +1 for each 0.065536 seconds of offset).
 			 */